set more 1
set linesize 200

*THIS FILE IS WRITTEN TO BE RUN AS A BATCH FILE

*IN THE STATEMENT IMMEDIATELY BELOW REPLACE OUR LOG DIRECTORY WITH YOURS
local logdir="C:\MurrellPaun\"
*IN THE STATEMENT IMMEDIATELY BELOW REPLACE OUR LOG FILE NAME WITH YOURS
local logname = "CaveatVenditor_PaperTables.log"
local logfile = "`logdir'"+"`logname'"
log using `logfile', replace
*IN THE STATEMENT IMMEDIATELY BELOW REPLACE OUR DATA DIRECTORY WITH YOURS
local datadir="C:\MurrellPaun\"
*IN THE STATEMENT IMMEDIATELY BELOW REPLACE OUR DATASET NAME WITH YOURS
local datasetname = "MurrellPaunRomaniaJLEODataAugust2016.dta"
local dataset = "`datadir'"+"`datasetname'"

use `dataset', clear

local x courtqd uncert_d2 first
local xct courtqc uncert_d2 first
local sx sinfo sdepend
local bx binfo bdepend
local z heavyind lightind constr
local sz buy1h buy1l buy1c buy1o buy2h buy2l buy2c  
local sza buy1l buy1c buy1o buy2h buy2l buy2c buy2o  
local bz sell1h sell1l sell1c sell1o sell2h sell2l sell2c
local bza sell1l sell1c sell1o sell2h sell2l sell2c sell2o
local rob state1 state2 statec loc age2 size

*THE SET OF RESULTS CONTAINED IN THE PAPER ITSELF******
*THAT IS TABLES 1 TO 5 IN THE BODY OF THE PAPER
*******************************************************

*TABLE 1. DESCRIPTIVE STATISTICS 
sum comp2 sspinv bspinv `x' `sx' `bx' constr heavyind lightind other buyer1 seller1 `sz' buy2o `bz' sell2o 

*TABLE 2: OLS Estimates of the Determinants of Detailed Contracting
*COLUMN (1) OF TABLE 2
reg comp2 `x' `sx' sspinv, cluster(id)
eststo m4
*COLUMN (2) OF TABLE 2
reg comp2 `x' `bx' bspinv, cluster(id)
eststo m5 
*COLUMN (3) of TABLE 2
reg comp2 `x' `sx' `bx' sspinv bspinv, cluster(id)
eststo m6 
test sspinv=bspinv
esttab m4 m5 m6 using `logdir'\scr.csv, se ar2 compress star(* 0.10 ** 0.05 *** 0.01) replace 

*TABLE 3: Maximum Likelihood Treatment-Effects Estimates of the Effect of Relationship-Specific Investment
*FIRST PART OF TABLE 3
treatreg comp2 `x' `sx', treat (sspinv=`sz') cluster(id)
eststo m3
*SECOND PART OF TABLE 3
treatreg comp2 `x' `bx', treat (bspinv=`bz') cluster(id)
eststo m4
esttab m3 m4 using `logdir'\scr1.csv, se ar2 compress star(* 0.10 ** 0.05 *** 0.01) replace 

*TABLE 4: Heckman Two-Step and Instrumental Variable Estimates of the Effect of Relationship-Specific Investment
*COLUMN (1) OF TABLE 4
treatreg comp2 `x' `sx', treat (sspinv=`sz') twostep  hazard(shaz)
eststo m3
*COLUMN (2) OF TABLE 4
treatreg comp2 `x' `bx', treat (bspinv=`bz') twostep  hazard(bhaz)
eststo m4
*COLUMN (3) OF TABLE 4
*do it symmetrically this way--note coefficients are good, but need to bootstrap for standard errors
reg comp2 `x' `sx' `bx' sspinv shaz bhaz bspinv, cluster(id)
scalar cfs = _b[sspinv] 
scalar cfb = _b[bspinv] 
scalar cfsz = _b[shaz] 
scalar cfbz = _b[bhaz] 
scalar cfd = _b[sspinv]-_b[bspinv] 
scalar numobs = e(N)
local numobs = numobs
eststo m5
esttab m3 m4 m5 using `logdir'\scr2.csv, se ar2 compress star(* 0.10 ** 0.05 *** 0.01) replace 
drop shaz bhaz
di cfs
di cfb
di numobs

capture program drop bootheck
program define bootheck, rclass
   preserve
	bsample
	treatreg comp2 courtqd uncert_d2 first sinfo sdepend, treat (sspinv=buy1h buy1l buy1c buy1o buy2h buy2l buy2c) twostep hazard(shaz)
	treatreg comp2 courtqd uncert_d2 first binfo bdepend, treat (bspinv=sell1h sell1l sell1c sell1o sell2h sell2l sell2c) twostep  hazard(bhaz)
	reg comp2 courtqd uncert_d2 first sinfo sdepend binfo bdepend sspinv shaz bspinv bhaz 
	return scalar cfo = _b[sspinv]-_b[bspinv] /*needs changing as appropriate*/
   restore
end
* reminders: *cfs = _b[sspinv] *cfb = _b[bspinv] *cfsz = _b[shaz] *cfbz = _b[bhaz] *cfd = _b[sspinv]-_b[bspinv] 
scalar observe = cfd
simulate scf = r(cfo), reps(1000) seed(1000): bootheck
bstat, stat(observe) n(`numobs')

*VERY IMPORTANT
use `dataset', clear

*WOOLDRIDGE'S MULTIPLE TREATMENT EFFECTS
*run probit of treatment w on 1, x and z, obtain the fitted probabilities G, run IV of y on 1, w, x using as instruments 1, G, x
probit sspinv `x' `sx' `sz' , cluster(id) 
predict GS
probit bspinv `x' `bx' `bz', cluster(id) 
predict GB
*COLUMN (4) OF TABLE 4
ivregress 2sls comp2 `x' `sx' (sspinv = GS ), cluster(id)
eststo m1
estat firststage
*COLUMN (5) of TABLE 4
ivregress 2sls comp2 `x' `bx' (bspinv = GB), cluster(id)
eststo m2
estat firststage
drop GS GB
probit sspinv `x' `sx' `bx' `sz' `bz', cluster(id) 
predict GS
probit bspinv `x' `sx' `bx' `sz' `bz', cluster(id) 
predict GB
*COLUMN (6) OF TABLE 4
ivregress 2sls comp2 `x' `sx' `bx' (bspinv sspinv = GS GB), cluster(id) 
eststo m3
estat firststage, all
test sspinv = bspinv
drop GS GB
esttab m1 m2 m3 using `logdir'\scr4.csv, se compress star(* 0.10 ** 0.05 *** 0.01) replace 

*OVERID TESTS FOR 2SLS MATCHING WOOLDRIDGE PROCEDURE ABOVE
*THESE ARE NOT IN THE TABLES BUT STATED IN THE TEXT
*SEE THE LAST PARAGRAPH OF SECTION 2.4
ivreg2 comp2 `x' `sx' (sspinv= `sz'), cluster(id) 
eststo m1
ivreg2 comp2 `x' `bx' (bspinv= `bz'), cluster(id) 
eststo m2
ivreg2 comp2 `x' `sx' `bx' (sspinv bspinv= `sz' `bz'), cluster(id)  
eststo m5
test sspinv = bspinv
*esttab m1 m2 m5 using `logdir'\scr.csv, se ar2 compress star(* 0.10 ** 0.05 *** 0.01) replace 

*TABLE 5: Maximum Likelihood Treatment-Effects Estimates with Identification Based on Non-Linearities
*FIRST PART OF TABLE 5
treatreg comp2 `x' `sx' `sz', treat (sspinv=`sz') cluster(id) 
eststo m3
*SECOND PART OF TABLE 5
treatreg comp2 `x' `bx' `bz', treat (bspinv=`bz') cluster(id) 
eststo m4
esttab m3 m4 using `logdir'\scr3.csv, se compress star(* 0.10 ** 0.05 *** 0.01) replace 

exit, clear